MODULE flx_oce
   !!======================================================================
   !!                 ***  MODULE  flx_oce  ***
   !!        parameter and  variables defined in memory in forced mode
   !!======================================================================
   !! History :
   !!   8.5  !  02-11  (C. Ethe)  F90: Free form and module
   !!----------------------------------------------------------------------
   !!  OPA 9.0 , LOCEAN-IPSL (2005) 
   !! $Header$ 
   !! This software is governed by the CeCILL licence see modipsl/doc/NEMO_CeCILL.txt 
   !!----------------------------------------------------------------------
   !! * Modules used
   USE par_oce          ! ocean parameters
# if defined key_lim3
   USE par_ice
# endif

   IMPLICIT NONE
   PRIVATE


   !!----------------------------------------------------------------------
   !! fluxes common variables
   !!----------------------------------------------------------------------
#if defined key_flx_forced_daily
   !!----------------------------------------------------------------------
   !! 'key_flx_forced_daily'
   !!----------------------------------------------------------------------
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   &  !:
      p_qt ,        &   !: total heat flux ( solar + non solar)
      p_qsr,        &   !: solar heat flux
      p_emp             !: evaporation minus precipitation            

#elif defined key_lim3 || defined key_lim2 || defined key_flx_bulk_monthly || defined key_flx_bulk_daily || defined key_flx_core

#if defined key_lim3 
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpl)    ::   &  !:
#elif defined key_lim2 
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj)    ::   &  !:
#endif
      qsr_ice  ,      &  !: solar flux over ice
      tn_ice   ,      &  !: ice surface temperature
      qnsr_ice ,      &  !: total non solar heat flux (Longwave downward radiation) over ice
      dqns_ice           !: total non solar sensibility over ice (LW+SEN+LA)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj)    ::   &  !:
      qsr_oce  ,      &  !: solar flux over ocean
      qnsr_oce ,      &  !: total non solar heat flux (Longwave downward radiation) over ocean 
      tprecip  ,      &  !: total precipitation ( or liquid precip minus evaporation in coupled mode)
      sprecip  ,      &  !: solid (snow) precipitation
      evap     ,      &  !: evaporation over ocean
      fr1_i0   ,      &  !: 1st part of the fraction of sol. rad.  which penetrate inside the ice cover
      fr2_i0             !: 2nd part of the fraction of sol. rad.  which penetrate inside the ice cover 
#if ! defined key_coupled
#if defined key_lim3 
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpl)    ::   &  !:
#elif defined key_lim2 
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj)    ::   &  !:
#endif
      qla_ice  ,      &  !: latent flux over ice  
      dqla_ice           !: latent sensibility over ice
#elif 
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj)    ::   &  !:
      rrunoff  ,      &  !: runoff
      calving  ,      &  !: calving
      alb_ice            !: albedo of ice      
#endif

#else
   !!----------------------------------------------------------------------
   !!   Default option                                         Empty module
   !!----------------------------------------------------------------------

#endif

   !!----------------------------------------------------------------------
END MODULE flx_oce
